#include <OI/oi.H>

#define XtNtimeStart		"timeStart"		/* start time resource name */
#define XtNtimeEnd		"timeEnd"		/* end time resource name */

#define XtCTimeStart		"TimeStart"		/* start time resource class */
#define XtCTimeEnd		"TimeEnd"		/* end time resource class */

#define DefaultTimeStart	"0800"			/* default start time */
#define DefaultTimeEnd		"1800"			/* default end time */

#define DefaultTimeInterval	30			/* default time interval (should also be a resource) */

typedef struct _MyRes {					/* structure to hold my resources */
	int		timeStart;
	int		timeEnd;
} MyRes;
MyRes MyResources;

static OI_resource resources[] = {
	{ XtNtimeStart, XtCTimeStart, XtRInt, sizeof(int), offsetof(MyRes, timeStart),
		XtRString, DefaultTimeStart, NULL_PMF, NULL, NULL_PMF, NULL },
	{ XtNtimeEnd, XtCTimeEnd, XtRInt, sizeof(int), offsetof(MyRes, timeEnd),
		XtRString, DefaultTimeEnd, NULL_PMF, NULL, NULL_PMF, NULL },
};

static XrmOptionDescRec opTable[] = {
	{"-start",	"*timeStart",	XrmoptionSepArg, (caddr_t)NULL },
	{"-end",	"*timeEnd",	XrmoptionSepArg, (caddr_t) NULL},
} ;

main (int argc, char **argv)
{
	OI_connection	*conp;				/* the connection to the server */
	OI_app_window	*appWindow;			/* the enclosing app window */
	OI_entry_field	*entryField;			/* used to create each entry field */
	int		time, row;			/* the current time and the row in which to put the entry field */
	char		*label;				/* the label for each entry field */
	char		*convertTime(int *);		/* convert a number into a time string */

	// Open a connection to the server
	if ((conp = OI_init(&argc, argv, "calendar", "Calendar", opTable, OI_count(opTable)))) {
		// go get the resources
		conp->get_resources(resources, OI_count(resources), (char *)&MyResources);
		// make sure the fetched resources are valid

		appWindow = oi_create_app_window("myapp", 10, 10, "Calendar");
		appWindow->set_layout(OI_layout_row);

		for (time = MyResources.timeStart, row = 0; time <= MyResources.timeEnd; time += DefaultTimeInterval) {
			label = convertTime(&time);
			entryField = oi_create_entry_field("timeSlot", 30, label, NULL, 30);
			entryField->layout_associated_object(appWindow, 0, row++, OI_ACTIVE);
		}
		appWindow->set_associated_object(conp->root(), OI_DEF_LOC, OI_DEF_LOC, OI_ACTIVE);

		OI_begin_interaction();
	}
	OI_fini();
}

char *
convertTime(int *time)
{
	static char label[20];
	int hour;
	int minute;

	hour = *time/100;
	minute = *time - (hour*100);
	if (minute >= 60) {
		minute -= 60;
		hour += 1;
	}
	*time = hour*100 + minute;
	sprintf(label, "%02d:%02d: ", hour, minute);
	return (label);
}